Package: Metrics
Version: 0.1.4
Title: Evaluation Metrics for Machine Learning
Description: An implementation of evaluation metrics in R that are commonly
             used in supervised machine learning. It implements metrics for
             regression, time series, binary classification, classification,
             and information retrieval problems. It has zero dependencies and
             a consistent, simple interface for all functions.
Authors@R: c(
    person("Ben", "Hamner", role = c("aut", "cph"), email = "ben@benhamner.com"),
    person("Michael", "Frasco", role = c("aut", "cre"), email = "mfrasco6@gmail.com"),
    person("Erin", "LeDell", role = c("ctb"), email = "oss@ledell.org"))
Maintainer: Michael Frasco <mfrasco6@gmail.com>
Suggests: testthat
URL: https://github.com/mfrasco/Metrics
BugReports: https://github.com/mfrasco/Metrics/issues
License: BSD_3_clause + file LICENSE
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-07-09 03:33:50 UTC; mfrasco
Author: Ben Hamner [aut, cph],
  Michael Frasco [aut, cre],
  Erin LeDell [ctb]
Repository: CRAN
Date/Publication: 2018-07-09 04:30:18 UTC
Built: R 4.4.0; ; 2024-04-30 21:19:12 UTC; unix
